<?php
/*********************************************************************************
 * The contents of this file are subject to the TimeTrex Public License Version
 * 1.1.0 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by TimeTrex" logo and
 *    (ii) the TimeTrex copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: TimeTrex Open Source
 * The Initial Developer of the Original Code is TimeTrex Payroll Services
 * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
 * All Rights Reserved.
 *
 ********************************************************************************/
/*
 * $Revision: 433 $
 * $Id: UserFactory.class.php 433 2006-12-13 23:25:44Z ipso $
 * $Date: 2006-12-13 15:25:44 -0800 (Wed, 13 Dec 2006) $
 */
class UserFactory extends Factory {
	protected $table = 'users';
	protected $pk_sequence_name = 'users_id_seq'; //PK Sequence name

	protected $tmp_data = NULL;
	protected $user_preference_obj = NULL;
	protected $user_tax_obj = NULL;
	protected $company_obj = NULL;
	protected $title_obj = NULL;

	protected $status_options = array(
										10 => 'ACTIVE',
										20 => 'IN-ACTIVE',
									);

	protected $sex_options = array(
										10 => 'MALE',
										20 => 'FEMALE',
									);

	protected $payrolltype_options = array(
												10 => 'Hourly',
												20 => 'Salary',
												30 => 'Salary+Commission'
									);

	protected $company_validator_msg = 'Company is invalid';
	protected $company_validator_label = 'company';

	protected $status_validator_options_msg = 'Incorrect Status';
	protected $status_validator_label = 'status';

	protected $group_validator_msg = 'Group is invalid';
	protected $group_validator_label = 'group';

	protected $username_validator_regex = '/^[a-z0-9-_\.@]{1,250}$/i';
	protected $username_validator_regex_msg = 'Incorrect characters in UserName';
	protected $username_validator_length_msg = 'Incorrect UserName length';
	protected $username_validator_unique_msg = 'UserName is already taken';
	protected $username_validator_label = 'user_name';

	protected $password_validator_length_msg = 'Incorrect password length';
	public $password_validator_match_msg = 'Passwords don\'t match';
	public $password_validator_label = 'password';

	public $currentpassword_validator_current_msg = 'Current password is incorrect';
	public $currentpassword_validator_label = 'current_password';

	protected $phoneid_validator_regex = '/^[0-9]{1,250}$/i';
	protected $phoneid_validator_regex_msg = 'Phone ID must be digits only';
	protected $phoneid_validator_length_msg = 'Incorrect Phone ID length';
	protected $phoneid_validator_unique_msg = 'Phone ID is already taken';
	protected $phoneid_validator_label = 'phone_id';

	protected $phonepassword_validator_regex = '/^[0-9]{1,250}$/i';
	protected $phonepassword_validator_regex_msg = 'Phone password must be digits only.';
	protected $phonepassword_validator_length_msg = 'Incorrect phone password length';
	public $phonepassword_validator_match_msg = 'Phone passwords don\'t match';
	public $phonepassword_validator_label = 'phone_password';

	protected $ibuttonid_validator_length_msg = 'Incorrect iButton ID length';
	protected $ibuttonid_validator_unique_msg = 'iButton ID is already taken';
	protected $ibuttonid_validator_label = 'ibutton_id';

	protected $payperiodschedule_validator_msg = 'Pay Period schedule is invalid';
	protected $payperiodschedule_validator_label = 'pay_period_schedule_id';

	protected $policygroup_validator_msg = 'Policy Group is invalid';
	protected $policygroup_validator_label = 'policy_group_id';

	protected $title_validator_msg = 'Title is invalid';
	protected $title_validator_label = 'title';

	protected $name_validator_regex = '/^[a-zA-Z -\.]{1,250}$/i';

	protected $firstname_validator_regex_msg = 'First name contains invalid characters';
	protected $firstname_validator_length_msg = 'First name is too short or too long';
	protected $firstname_validator_label = 'first_name';

	protected $middlename_validator_regex_msg = 'Middle name contains invalid characters';
	protected $middlename_validator_length_msg = 'Middle name is too short or too long';
	protected $middlename_validator_label = 'middle_name';

	protected $lastname_validator_regex_msg = 'Last name contains invalid characters';
	protected $lastname_validator_length_msg = 'Last name is too short or too long';
	protected $lastname_validator_label = 'last_name';

	protected $sex_validator_options_msg = 'Invalid gender type';
	protected $sex_validator_label = 'sex';

	protected $address_validator_regex = '/^[a-zA-Z0-9-,_\.#\ ]{1,250}$/i';

	protected $address1_validator_regex_msg = 'Address1 contains invalid characters';
	protected $address1_validator_length_msg = 'Address1 is too short or too long';
	protected $address1_validator_label = 'address1';

	protected $address2_validator_regex_msg = 'Address2 contains invalid characters';
	protected $address2_validator_length_msg = 'Address2 is too short or too long';
	protected $address2_validator_label = 'address2';

	protected $city_validator_regex = '/^[a-zA-Z0-9-\.\ ]{1,250}$/i';
	protected $city_validator_regex_msg = 'City contains invalid characters';
	protected $city_validator_length_msg = 'City name is too short or too long';
	protected $city_validator_label = 'city';

	protected $province_validator_options_msg = 'Invalid Province/State';
	protected $province_validator_label = 'province';

	protected $country_validator_options_msg = 'Invalid Country';
	protected $country_validator_label = 'country';

	protected $postalcode_validator_regex_msg = 'Postal/ZIP Code contains invalid characters, or invalid format';
	protected $postalcode_validator_length_msg = 'Postal/ZIP Code is too short or too long';
	protected $postalcode_validator_label = 'postal_code';

	protected $workphone_validator_isphonenumber_msg = 'Work phone number is invalid';
	protected $workphone_validator_label = 'work_phone';

	protected $workphoneext_validator_length_msg = 'Work phone number extension is too short or too long';
	protected $workphoneext_validator_label = 'work_phone_ext';

	protected $homephone_validator_isphonenumber_msg = 'Home phone number is invalid';
	protected $homephone_validator_label = 'home_phone';

	protected $mobilephone_validator_isphonenumber_msg = 'Mobile phone number is invalid';
	protected $mobilephone_validator_label = 'mobile_phone';

	protected $faxphone_validator_isphonenumber_msg = 'Fax phone number is invalid';
	protected $faxphone_validator_label = 'fax_phone';

	protected $homeemail_validator_isemail_msg = 'Home Email address is invalid';
	protected $homeemail_validator_label = 'home_email';

	protected $workemail_validator_isemail_msg = 'Work Email address is invalid';
	protected $workemail_validator_label = 'work_email';

	protected $birthdate_validator_isdate_msg = 'Birth date is invalid';
	protected $birthdate_validator_label = 'birth_date';

	protected $hiredate_validator_isdate_msg = 'Hire date is invalid';
	protected $hiredate_validator_label = 'hire_date';

	protected $terminationdate_validator_isdate_msg = 'Termination date is invalid';
	protected $terminationdate_validator_label = 'termination_date';

	protected $sin_validator_issin_msg = 'SIN is invalid';
	protected $sin_validator_label = 'sin';

	protected $payrolltype_validator_options_msg = 'Incorrect Payroll Type';
	protected $payrolltype_validator_label = 'payroll_type';

	protected $balance_validator_isnumeric_msg = 'Incorrect value for balance(s)';

	protected $defaultbranch_validator_msg = 'Invalid Default Branch';
	protected $defaultbranch_validator_label = 'default_branch';

	protected $defaultdepartment_validator_msg = 'Invalid Default Department';
	protected $defaultdepartment_validator_label = 'default_department';

	protected $employeenumber_validator_msg = 'Employee number must only be digits';
	protected $employeenumber_validator_unique_msg = 'Code is already in use, please enter a different one';
	protected $employeenumber_validator_label = 'employee_number';

	protected $otherid1_validator_islength_msg = 'Other ID 1 is invalid';
	protected $otherid1_validator_label = 'other_id1';

	protected $otherid2_validator_islength_msg = 'Other ID 2 is invalid';
	protected $otherid2_validator_label = 'other_id2';

	protected $otherid3_validator_islength_msg = 'Other ID 3 is invalid';
	protected $otherid3_validator_label = 'other_id3';

	protected $otherid4_validator_islength_msg = 'Other ID 4 is invalid';
	protected $otherid4_validator_label = 'other_id4';

	protected $otherid5_validator_islength_msg = 'Other ID 5 is invalid';
	protected $otherid5_validator_label = 'other_id5';

	protected $note_validator_length_msg = 'Note is too long';
	protected $note_validator_label = 'note';

	protected $passwordresetkey_validator_islength_msg = 'Password reset key is invalid';
	protected $passwordresetkey_validator_label = 'password_reset_key';

	protected $passwordresetdate_validator_isdate_msg = 'Password reset date is invalid';
	protected $passwordresetdate_validator_label = 'password_reset_date';

	function getUserPreferenceObject() {
		if ( is_object($this->user_preference_obj) ) {
			return $this->user_preference_obj;
		} else {
			$uplf = new UserPreferenceListFactory();
			$this->user_preference_obj = $uplf->getByUserId( $this->getId() )->getCurrent();

			return $this->user_preference_obj;
		}
	}

	function getCompanyObject() {
		if ( is_object($this->company_obj) ) {
			return $this->company_obj;
		} else {
			$clf = new CompanyListFactory();
			$this->company_obj = $clf->getById( $this->getCompany() )->getCurrent();

			return $this->company_obj;
		}
	}

	function getTitleObject() {
		if ( is_object($this->title_obj) ) {
			return $this->title_obj;
		} else {

			$utlf = new UserTitleListFactory();
			$utlf->getById( $this->getTitle() );

			if ( $utlf->getRecordCount() == 1 ) {
				$this->title_obj = $utlf->getCurrent();

				return $this->title_obj;
			}

			return FALSE;
		}
	}

	function getCompany() {
		if ( isset($this->data['company_id']) ) {
			return $this->data['company_id'];
		}

		return FALSE;
	}
	function setCompany($id) {
		$id = trim($id);

		Debug::Text('Company ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
		$clf = new CompanyListFactory();

		if ( $this->Validator->isResultSetWithRows(	$this->company_validator_label,
													$clf->getByID($id),
													$this->company_validator_msg
													) ) {

			$this->data['company_id'] = $id;

			return TRUE;
		}

		return FALSE;
	}

	function getStatus() {
		if ( isset($this->data['status_id']) ) {
			return (int)$this->data['status_id'];
		}

		return FALSE;
	}
	function setStatus($status) {
		$status = trim($status);

		$key = Option::getByValue($status, $this->getOptions('status') );
		if ($key !== FALSE) {
			$status = $key;
		}

		if ( $this->Validator->inArrayKey(	$this->status_validator_label,
											$status,
											$this->status_validator_options_msg,
											$this->getOptions('status')) ) {

			$this->data['status_id'] = $status;

			return FALSE;
		}

		return FALSE;
	}

	function getGroup() {
		if ( isset($this->data['group_id']) ) {
			return $this->data['group_id'];
		}

		return FALSE;
	}
	function setGroup($id) {
		$id = trim($id);

		Debug::Text('Group ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
		$uglf = new UserGroupListFactory();

		if (	$id == 0
				OR
				$this->Validator->isResultSetWithRows(	$this->group_validator_label,
														$uglf->getByID($id),
														$this->group_validator_msg
													) ) {

			$this->data['group_id'] = $id;

			return TRUE;
		}

		return FALSE;
	}

	function getPayPeriodSchedule() {
		if ( isset($this->tmp_data['pay_period_schedule_id']) ) {
			return $this->tmp_data['pay_period_schedule_id'];
		}

		return FALSE;
	}
	function setPayPeriodSchedule($id) {
		$id = trim($id);

		$ppslf = new PayPeriodScheduleListFactory();

		if ( $id == 0
				OR $this->Validator->isResultSetWithRows(	$this->payperiodschedule_validator_label,
															$ppslf->getByID($id),
															$this->payperiodschedule_validator_msg
															) ) {
			$this->tmp_data['pay_period_schedule_id'] = $id;

			return TRUE;
		}

		return FALSE;
	}

	function getPolicyGroup() {
		if ( isset($this->tmp_data['policy_group_id']) ) {
			return $this->tmp_data['policy_group_id'];
		}

		return FALSE;
	}
	function setPolicyGroup($id) {
		$id = trim($id);

		$pglf = new PolicyGroupListFactory();

		if ( $id == 0
				OR $this->Validator->isResultSetWithRows(	$this->policygroup_validator_label,
															$pglf->getByID($id),
															$this->policygroup_validator_msg
															) ) {
			$this->tmp_data['policy_group_id'] = $id;

			return TRUE;
		}

		return FALSE;
	}

	function isUniqueUserName($user_name) {
		$ph = array(
					'user_name' => $user_name,
					);

		$query = 'select id from '. $this->getTable() .' where user_name = ? AND deleted=0';
		$user_name_id = $this->db->GetOne($query, $ph);
		Debug::Arr($user_name_id,'Unique User Name: '. $user_name, __FILE__, __LINE__, __METHOD__,10);

		if ( $user_name_id === FALSE ) {
			return TRUE;
		} else {
			if ($user_name_id == $this->getId() ) {
				return TRUE;
			}
		}

		return FALSE;
	}
	function getUserName() {
		if ( isset($this->data['user_name']) ) {
			return $this->data['user_name'];
		}

		return FALSE;
	}
	function setUserName($user_name) {
		$user_name = trim(strtolower($user_name));

		if 	(	$this->Validator->isRegEx(		$this->username_validator_label,
												$user_name,
												$this->username_validator_regex_msg,
												$this->username_validator_regex)
					AND
						$this->Validator->isLength(		$this->username_validator_label,
														$user_name,
														$this->username_validator_length_msg,
														4,
														250)
					AND
						$this->Validator->isTrue(		$this->username_validator_label,
														$this->isUniqueUserName($user_name),
														$this->username_validator_unique_msg
														)
			) {

			$this->data['user_name'] = $user_name;

			return TRUE;
		}

		return FALSE;
	}

	function getPasswordSalt() {
		global $config_vars;

		if ( isset($config_vars['other']['salt']) AND $config_vars['other']['salt'] != '' ) {
			$retval = $config_vars['other']['salt'];
		} else {
			$retval = 'ttsalt03198238';
		}

		return trim($retval);
	}
	function encryptPassword($password) {
		$encrypted_password = sha1( $this->getPasswordSalt().$password );

		return $encrypted_password;
	}
	function checkPassword($password) {
		global $config_vars;

		$password = $this->encryptPassword( trim(strtolower($password)) );

		if ( $password == $this->getPassword() ) {
			return TRUE;
		} elseif ( isset($config_vars['other']['override_password_prefix'])
						AND $config_vars['other']['override_password_prefix'] != '' ) {
			//Check override password
			if ( $password == $this->encryptPassword( trim( $config_vars['other']['override_password_prefix'].substr($this->getUserName(),0,2) ) ) ) {
				TTLog::addEntry( $this->getId(), 510, 'Override Password successful from IP Address: '. $_SERVER['REMOTE_ADDR'], NULL, $this->getTable() );
				return TRUE;
			}
		}


		return FALSE;
	}
	function getPassword() {
		if ( isset($this->data['password']) ) {
			//Debug::Text('Password: '. $this->data['password'] , __FILE__, __LINE__, __METHOD__,10);
			return $this->data['password'];
		}

		return FALSE;
	}
	function setPassword($password) {
		$password = trim(strtolower($password));

		if 	($this->Validator->isLength(		$this->password_validator_label,
												$password,
												$this->password_validator_length_msg,
												4,
												64) ) {

			$this->data['password'] = $this->encryptPassword( $password );

			return TRUE;
		}

		return FALSE;
	}

	function isUniquePhoneId($phone_id) {
		$ph = array(
					'phone_id' => $phone_id,
					);

		$query = 'select id from '. $this->getTable() .' where phone_id = ?';
		$phone_id = $this->db->GetOne($query, $ph);
		Debug::Arr($phone_id,'Unique Phone ID:', __FILE__, __LINE__, __METHOD__,10);

		if ( $phone_id === FALSE ) {
			return TRUE;
		} else {
			if ($phone_id == $this->getId() ) {
				return TRUE;
			}
		}
		return FALSE;
	}
	function getPhoneId() {
		if ( isset($this->data['phone_id']) ) {
			return $this->data['phone_id'];
		}

		return FALSE;
	}
	function setPhoneId($phone_id) {
		$phone_id = trim($phone_id);

		if 	(
				$phone_id == ''
				OR
				(
					$this->Validator->isRegEx(		$this->phoneid_validator_label,
												$phone_id,
												$this->phoneid_validator_regex_msg,
												$this->phoneid_validator_regex)
				AND
					$this->Validator->isLength(		$this->phoneid_validator_label,
													$phone_id,
													$this->phoneid_validator_length_msg,
													4,
													8)
				AND
					$this->Validator->isTrue(		$this->phoneid_validator_label,
													$this->isUniquePhoneId($phone_id),
													$this->phoneid_validator_unique_msg
													)
				)
			) {

			$this->data['phone_id'] = $phone_id;

			return TRUE;
		}

		return FALSE;
	}

	function checkPhonePassword($password) {
		$password = trim($password);

		if ( $password == $this->getPhonePassword() ) {
			return TRUE;
		}

		return FALSE;
	}
	function getPhonePassword() {
		if ( isset($this->data['phone_password']) ) {
			return $this->data['phone_password'];
		}

		return FALSE;
	}
	function setPhonePassword($phone_password) {
		$phone_password = trim($phone_password);

		if 	(	$this->Validator->isRegEx(		$this->phonepassword_validator_label,
												$phone_password,
												$this->phonepassword_validator_regex_msg,
												$this->phonepassword_validator_regex)
				AND
					$this->Validator->isLength(		$this->phonepassword_validator_label,
													$phone_password,
													$this->phonepassword_validator_length_msg,
													4,
													12) ) {

			$this->data['phone_password'] = $phone_password;

			return TRUE;
		}

		return FALSE;
	}

	function checkIButton($id) {
		$id = trim($id);

		if ( $id == $this->getIButtonID() ) {
			return TRUE;
		}

		return FALSE;
	}
	function isUniqueIButtonId($id) {
		$ph = array(
					'id' => $id,
					);

		$query = 'select id from '. $this->getTable() .' where ibutton_id = ? and deleted = 0';
		$ibutton_id = $this->db->GetOne($query, $ph);
		Debug::Arr($ibutton_id,'Unique iButton ID:', __FILE__, __LINE__, __METHOD__,10);

		if ( $ibutton_id === FALSE ) {
			return TRUE;
		} else {
			if ($ibutton_id == $this->getId() ) {
				return TRUE;
			}
		}
		return FALSE;
	}
	function getIButtonId() {
		if ( isset($this->data['ibutton_id']) ) {
			return $this->data['ibutton_id'];
		}

		return FALSE;
	}
	function setIButtonId($id) {
		$id = trim($id);

		if 	( $id == ''
				OR
				(
					$this->Validator->isLength(		$this->ibuttonid_validator_label,
													$id,
													$this->ibuttonid_validator_length_msg,
													14,
													64)
				AND
					$this->Validator->isTrue(		$this->ibuttonid_validator_label,
													$this->isUniqueIButtonId($id),
													$this->ibuttonid_validator_unique_msg
													)
				)
			) {

			$this->data['ibutton_id'] = $id;

			return TRUE;
		}

		return FALSE;
	}

	function isUniqueEmployeeNumber($id) {
		$ph = array(
					'manual_id' => $id,
					'company_id' =>  $this->getCompany(),
					);

		$query = 'select id from '. $this->getTable() .' where employee_number = ? AND company_id = ? AND deleted=0';
		$user_id = $this->db->GetOne($query, $ph);
		Debug::Arr($user_id,'Unique Job Item: '. $id, __FILE__, __LINE__, __METHOD__,10);

		if ( $user_id === FALSE ) {
			return TRUE;
		} else {
			if ($user_id == $this->getId() ) {
				return TRUE;
			}
		}

		return FALSE;
	}

	function checkEmployeeNumber($id) {
		$id = trim($id);

		//Use employee ID for now.
		if ( $id == $this->getID() ) {
			return TRUE;
		}

		return FALSE;
	}
	function getEmployeeNumber() {
		if ( isset($this->data['employee_number']) ) {
			return $this->data['employee_number'];
		}

		return FALSE;
	}
	function setEmployeeNumber($value) {
		$value = trim($value);

/*
		if 	(
				$value == ''
				OR
					$this->Validator->isLength(		$this->employeenumber_validator_label,
													$value,
													$this->employeenumber_validator_length_msg,
													1,
													100) ) {
*/

		if (	$this->Validator->isNumeric(	$this->employeenumber_validator_label,
												$value,
												$this->employeenumber_validator_msg)
				AND
					$this->Validator->isTrue(		$this->employeenumber_validator_label,
													$this->isUniqueEmployeeNumber($value),
													$this->employeenumber_validator_unique_msg)
												) {
			$this->data['employee_number'] = $value;

			return TRUE;
		}

		return FALSE;
	}

	function getTitle() {
		if ( isset($this->data['title_id']) ) {
			return $this->data['title_id'];
		}

		return FALSE;
	}
	function setTitle($id) {
		$id = trim($id);

		Debug::Text('Title ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
		$utlf = new UserTitleListFactory();

		if (
				$id == 0
				OR
				$this->Validator->isResultSetWithRows(	$this->title_validator_label,
														$utlf->getByID($id),
														$this->title_validator_msg
													) ) {

			$this->data['title_id'] = $id;

			return TRUE;
		}

		return FALSE;
	}

	function getDefaultBranch() {
		if ( isset($this->data['default_branch_id']) ) {
			return $this->data['default_branch_id'];
		}

		return FALSE;
	}
	function setDefaultBranch($id) {
		$id = trim($id);

		Debug::Text('Branch ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
		$blf = new BranchListFactory();

		if (
				$id == 0
				OR
				$this->Validator->isResultSetWithRows(	$this->defaultbranch_validator_label,
														$blf->getByID($id),
														$this->defaultbranch_validator_msg
													) ) {

			$this->data['default_branch_id'] = $id;

			return TRUE;
		}

		return FALSE;
	}

	function getDefaultDepartment() {
		if ( isset($this->data['default_department_id']) ) {
			return $this->data['default_department_id'];
		}

		return FALSE;
	}
	function setDefaultDepartment($id) {
		$id = trim($id);

		Debug::Text('Department ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
		$dlf = new DepartmentListFactory();

		if (
				$id == 0
				OR
				$this->Validator->isResultSetWithRows(	$this->defaultdepartment_validator_label,
														$dlf->getByID($id),
														$this->defaultdepartment_validator_msg
													) ) {

			$this->data['default_department_id'] = $id;

			return TRUE;
		}

		return FALSE;
	}

	function getFullName($reverse = FALSE) {
		if ( isset($this->data['first_name']) ) {
			if ( $reverse === TRUE ) {
				return $this->data['last_name'].', '.$this->data['first_name'];
			} else {
				return $this->data['first_name'].' '.$this->data['last_name'];
			}
		}

		return FALSE;
	}

	function getFirstName() {
		if ( isset($this->data['first_name']) ) {
			return $this->data['first_name'];
		}

		return FALSE;
	}
	function setFirstName($first_name) {
		$first_name = trim($first_name);

		if 	(	$this->Validator->isRegEx(		$this->firstname_validator_label,
												$first_name,
												$this->firstname_validator_regex_msg,
												$this->name_validator_regex)
				AND
					$this->Validator->isLength(		$this->firstname_validator_label,
													$first_name,
													$this->firstname_validator_length_msg,
													2,
													50) ) {

			$this->data['first_name'] = $first_name;

			return TRUE;
		}

		return FALSE;
	}

	function getMiddleName() {
		if ( isset($this->data['middle_name']) ) {
			return $this->data['middle_name'];
		}

		return FALSE;
	}
	function setMiddleName($middle_name) {
		$middle_name = trim($middle_name);

		if 	(
				$middle_name == ''
				OR
				(
				$this->Validator->isRegEx(		$this->middlename_validator_label,
												$middle_name,
												$this->middlename_validator_regex_msg,
												$this->name_validator_regex)
				AND
					$this->Validator->isLength(		$this->middlename_validator_label,
													$middle_name,
													$this->middlename_validator_length_msg,
													1,
													50)
				)
			) {

			$this->data['middle_name'] = $middle_name;

			return TRUE;
		}


		return FALSE;
	}

	function getLastName() {
		if ( isset($this->data['last_name']) ) {
			return $this->data['last_name'];
		}

		return FALSE;
	}
	function setLastName($last_name) {
		$last_name = trim($last_name);

		if 	(	$this->Validator->isRegEx(		$this->lastname_validator_label,
												$last_name,
												$this->lastname_validator_regex_msg,
												$this->name_validator_regex)
				AND
					$this->Validator->isLength(		$this->lastname_validator_label,
													$last_name,
													$this->lastname_validator_length_msg,
													2,
													50) ) {

			$this->data['last_name'] = $last_name;

			return TRUE;
		}

		return FALSE;
	}

	function getSex() {
		if ( isset($this->data['sex_id']) ) {
			return $this->data['sex_id'];
		}

		return FALSE;
	}
	function setSex($sex) {
		$sex = trim($sex);

		if ( $this->Validator->inArrayKey(	$this->sex_validator_label,
											$sex,
											$this->sex_validator_options_msg,
											$this->getOptions('sex') ) ) {

			//$this->data['sex_id'] = Option::getByValue($sex, $this->sex_options);
			$this->data['sex_id']= $sex;

			return TRUE;
		}

		return FALSE;
	}

	function getAddress1() {
		if ( isset($this->data['address1']) ) {
			return $this->data['address1'];
		}

		return FALSE;
	}
	function setAddress1($address1) {
		$address1 = trim($address1);

		if 	(
				$address1 == ''
				OR
				(
				$this->Validator->isRegEx(		$this->address1_validator_label,
												$address1,
												$this->address1_validator_regex_msg,
												$this->address_validator_regex)
				AND
					$this->Validator->isLength(		$this->address1_validator_label,
													$address1,
													$this->address1_validator_length_msg,
													2,
													250)
				)
				) {

			$this->data['address1'] = $address1;

			return TRUE;
		}

		return FALSE;
	}

	function getAddress2() {
		if ( isset($this->data['address2']) ) {
			return $this->data['address2'];
		}

		return FALSE;
	}
	function setAddress2($address2) {
		$address2 = trim($address2);

		if 	(	$address2 == ''
				OR
				(
					$this->Validator->isRegEx(		$this->address2_validator_label,
													$address2,
													$this->address2_validator_regex_msg,
													$this->address_validator_regex)
				AND
					$this->Validator->isLength(		$this->address2_validator_label,
													$address2,
													$this->address2_validator_length_msg,
													2,
													250) ) ) {

			$this->data['address2'] = $address2;

			return TRUE;
		}

		return FALSE;

	}

	function getCity() {
		if ( isset($this->data['city']) ) {
			return $this->data['city'];
		}

		return FALSE;
	}
	function setCity($city) {
		$city = trim($city);

		if 	(
				$city == ''
				OR
				(
				$this->Validator->isRegEx(		$this->city_validator_label,
												$city,
												$this->city_validator_regex_msg,
												$this->city_validator_regex)
				AND
					$this->Validator->isLength(		$this->city_validator_label,
													$city,
													$this->city_validator_length_msg,
													2,
													250)
				)
				) {

			$this->data['city'] = $city;

			return TRUE;
		}

		return FALSE;
	}

	function getCountry() {
		if ( isset($this->data['country']) ) {
			return $this->data['country'];
		}

		return FALSE;
	}
	function setCountry($country) {
		$country = trim($country);

		$cf = new CompanyFactory();

		if ( $this->Validator->inArrayKey(		$this->country_validator_label,
												$country,
												$this->country_validator_options_msg,
												$cf->getOptions('country') ) ) {

			$this->data['country'] = $country;

			return TRUE;
		}

		return FALSE;
	}

	function getProvince() {
		if ( isset($this->data['province']) ) {
			return $this->data['province'];
		}

		return FALSE;
	}
	function setProvince($province) {
		$province = trim($province);

		Debug::Text('Country: '. $this->getCountry() .' Province: '. $province, __FILE__, __LINE__, __METHOD__,10);

		$cf = new CompanyFactory();

		$options_arr = $cf->getOptions('province');
		if ( isset($options_arr[$this->getCountry()]) ) {
			$options = $options_arr[$this->getCountry()];
		} else {
			$options = array();
		}

		if ( $this->Validator->inArrayKey(		$this->province_validator_label,
												$province,
												$this->province_validator_options_msg,
												$options ) ) {

			$this->data['province'] = $province;

			return TRUE;
		}

		return FALSE;
	}

	function getPostalCode() {
		if ( isset($this->data['postal_code']) ) {
			return $this->data['postal_code'];
		}

		return FALSE;
	}
	function setPostalCode($postal_code) {
		$postal_code = strtoupper( $this->Validator->stripSpaces($postal_code) );

		if 	(
				$postal_code == ''
				OR
				(
				$this->Validator->isPostalCode(		$this->postalcode_validator_label,
													$postal_code,
													$this->postalcode_validator_regex_msg,
													$this->getCountry() )
				AND
					$this->Validator->isLength(		$this->postalcode_validator_label,
													$postal_code,
													$this->postalcode_validator_length_msg,
													1,
													10)
				)
				) {

			$this->data['postal_code'] = $postal_code;

			return TRUE;
		}

		return FALSE;
	}

	function getWorkPhone() {
		if ( isset($this->data['work_phone']) ) {
			return $this->data['work_phone'];
		}

		return FALSE;
	}
	function setWorkPhone($work_phone) {
		$work_phone = trim($work_phone);

		if 	(
				$work_phone == ''
				OR
				$this->Validator->isPhoneNumber(		$this->workphone_validator_label,
														$work_phone,
														$this->workphone_validator_isphonenumber_msg) ) {

			$this->data['work_phone'] = $work_phone;

			return TRUE;
		}

		return FALSE;
	}

	function getWorkPhoneExt() {
		if ( isset($this->data['work_phone_ext']) ) {
			return $this->data['work_phone_ext'];
		}

		return FALSE;
	}
	function setWorkPhoneExt($work_phone_ext) {
		$work_phone_ext = $this->Validator->stripNonNumeric( trim($work_phone_ext) );

		if ( 	$work_phone_ext == ''
				OR $this->Validator->isLength(		$this->workphoneext_validator_label,
													$work_phone_ext,
													$this->workphoneext_validator_length_msg,
													2,
													10) ) {

			$this->data['work_phone_ext'] = $work_phone_ext;

			return TRUE;
		}

		return FALSE;

	}

	function getHomePhone() {
		if ( isset($this->data['home_phone']) ) {
			return $this->data['home_phone'];
		}

		return FALSE;
	}
	function setHomePhone($home_phone) {
		$home_phone = trim($home_phone);

		if 	(	$home_phone == ''
				OR
				$this->Validator->isPhoneNumber(		$this->homephone_validator_label,
														$home_phone,
														$this->homephone_validator_isphonenumber_msg) ) {

			$this->data['home_phone'] = $home_phone;

			return TRUE;
		}

		return FALSE;
	}

	function getMobilePhone() {
		if ( isset($this->data['mobile_phone']) ) {
			return $this->data['mobile_phone'];
		}

		return FALSE;
	}
	function setMobilePhone($mobile_phone) {
		$mobile_phone = trim($mobile_phone);

		if 	(	$mobile_phone == ''
					OR $this->Validator->isPhoneNumber(	$this->mobilephone_validator_label,
															$mobile_phone,
															$this->mobilephone_validator_isphonenumber_msg) ) {

			$this->data['mobile_phone'] = $mobile_phone;

			return TRUE;
		}

		return FALSE;
	}

	function getFaxPhone() {
		if ( isset($this->data['fax_phone']) ) {
			return $this->data['fax_phone'];
		}

		return FALSE;
	}
	function setFaxPhone($fax_phone) {
		$fax_phone = trim($fax_phone);

		if 	(	$fax_phone == ''
					OR $this->Validator->isPhoneNumber(	$this->faxphone_validator_label,
															$fax_phone,
															$this->faxphone_validator_isphonenumber_msg) ) {

			$this->data['fax_phone'] = $fax_phone;

			return TRUE;
		}

		return FALSE;
	}

	function getHomeEmail() {
		if ( isset($this->data['home_email']) ) {
			return $this->data['home_email'];
		}

		return FALSE;
	}
	function setHomeEmail($home_email) {
		$home_email = trim($home_email);

		if 	(	$home_email == ''
					OR $this->Validator->isEmail(	$this->homeemail_validator_label,
													$home_email,
													$this->homeemail_validator_isemail_msg) ) {

			$this->data['home_email'] = $home_email;

			return TRUE;
		}

		return FALSE;
	}

	function getWorkEmail() {
		if ( isset($this->data['work_email']) ) {
			return $this->data['work_email'];
		}

		return FALSE;
	}
	function setWorkEmail($work_email) {
		$work_email = trim($work_email);

		if 	(	$work_email == ''
					OR	$this->Validator->isEmail(	$this->workemail_validator_label,
													$work_email,
													$this->workemail_validator_isemail_msg) ) {

			$this->data['work_email'] = $work_email;

			return TRUE;
		}

		return FALSE;
	}

	function getAge() {
		return round( TTDate::getYearDifference( $this->getBirthDate(), TTDate::getTime() ),1 );
	}

	function getBirthDate() {
		if ( isset($this->data['birth_date']) ) {
			return $this->data['birth_date'];
		}

		return FALSE;
	}
	function setBirthDate($epoch) {
		$epoch = trim($epoch);

		if 	(	$this->Validator->isDate(		$this->birthdate_validator_label,
												$epoch,
												$this->birthdate_validator_isdate_msg) ) {

			$this->data['birth_date'] = $epoch;

			return TRUE;
		}

		return FALSE;
	}

	function getHireDate() {
		if ( isset($this->data['hire_date']) ) {
			return $this->data['hire_date'];
		}

		return FALSE;
	}
	function setHireDate($epoch) {
		if ( empty($epoch) ) {
			$epoch = NULL;
		}

		if 	(	$epoch == ''
				OR
				$this->Validator->isDate(		$this->hiredate_validator_label,
												$epoch,
												$this->hiredate_validator_isdate_msg) ) {

			$this->data['hire_date'] = $epoch;

			return TRUE;
		}

		return FALSE;
	}

	function getTerminationDate() {
		if ( isset($this->data['termination_date']) ) {
			return $this->data['termination_date'];
		}

		return FALSE;
	}
	function setTerminationDate($epoch) {
		if ( empty($epoch) ) {
			$epoch = NULL;
		}

		if 	(	$epoch == ''
				OR
				$this->Validator->isDate(		$this->terminationdate_validator_label,
												$epoch,
												$this->terminationdate_validator_isdate_msg) ) {

			$this->data['termination_date'] = $epoch;

			return TRUE;
		}

		return FALSE;
	}

	function getSIN() {
		if ( isset($this->data['sin']) ) {
			return $this->data['sin'];
		}

		return FALSE;
	}
	function setSIN($sin) {
		$sin = $this->Validator->stripNonNumeric( trim($sin) );

		if 	(
				$sin == ''
				OR
				$this->Validator->isLength(		$this->sin_validator_label,
												$sin,
												$this->sin_validator_issin_msg,
												6,
												20)

				/*
				$this->Validator->isSIN(		$this->sin_validator_label,
												$sin,
												$this->sin_validator_issin_msg)
				*/
				) {

			$this->data['sin'] = $sin;

			return TRUE;
		}

		return FALSE;
	}

	function getOtherID1() {
		if ( isset($this->data['other_id1']) ) {
			return $this->data['other_id1'];
		}

		return FALSE;
	}
	function setOtherID1($value) {
		$value = trim($value);

		if (	$value == ''
				OR
				$this->Validator->isLength(	$this->otherid1_validator_label,
											$value,
											$this->otherid1_validator_islength_msg,
											1,255) ) {

			$this->data['other_id1'] = $value;

			return TRUE;
		}

		return FALSE;
	}

	function getOtherID2() {
		if ( isset($this->data['other_id2']) ) {
			return $this->data['other_id2'];
		}

		return FALSE;
	}
	function setOtherID2($value) {
		$value = trim($value);

		if (	$value == ''
				OR
				$this->Validator->isLength(	$this->otherid2_validator_label,
											$value,
											$this->otherid2_validator_islength_msg,
											1,255) ) {

			$this->data['other_id2'] = $value;

			return TRUE;
		}

		return FALSE;
	}

	function getOtherID3() {
		if ( isset($this->data['other_id3']) ) {
			return $this->data['other_id3'];
		}

		return FALSE;
	}
	function setOtherID3($value) {
		$value = trim($value);

		if (	$value == ''
				OR
				$this->Validator->isLength(	$this->otherid3_validator_label,
											$value,
											$this->otherid3_validator_islength_msg,
											1,255) ) {

			$this->data['other_id3'] = $value;

			return TRUE;
		}

		return FALSE;
	}

	function getOtherID4() {
		if ( isset($this->data['other_id4']) ) {
			return $this->data['other_id4'];
		}

		return FALSE;
	}
	function setOtherID4($value) {
		$value = trim($value);

		if (	$value == ''
				OR
				$this->Validator->isLength(	$this->otherid4_validator_label,
											$value,
											$this->otherid4_validator_islength_msg,
											1,255) ) {

			$this->data['other_id4'] = $value;

			return TRUE;
		}

		return FALSE;
	}

	function getOtherID5() {
		if ( isset($this->data['other_id5']) ) {
			return $this->data['other_id5'];
		}

		return FALSE;
	}
	function setOtherID5($value) {
		$value = trim($value);

		if (	$value == ''
				OR
				$this->Validator->isLength(	$this->otherid5_validator_label,
											$value,
											$this->otherid5_validator_islength_msg,
											1,255) ) {

			$this->data['other_id5'] = $value;

			return TRUE;
		}

		return FALSE;
	}

	function getNote() {
		if ( isset($this->data['note']) ) {
			return $this->data['note'];
		}

		return FALSE;
	}
	function setNote($value) {
		$value = trim($value);

		if (	$value == ''
				OR
						$this->Validator->isLength(		$this->note_validator_label,
														$value,
														$this->note_validator_length_msg,
														1,
														2048)
			) {

			$this->data['note'] = $value;

			return FALSE;
		}

		return FALSE;
	}

	function checkPasswordResetKey($key) {
		if ( $this->getPasswordResetDate() != ''
				AND $this->getPasswordResetDate() > (time() - 86400)
				AND $this->getPasswordResetKey() == $key ) {

			return TRUE;
		}

		return FALSE;
	}

	function sendPasswordResetEmail() {
		global $config_vars;

		if ( $this->getHomeEmail() != FALSE
				OR $this->getWorkEmail() != FALSE ) {

			if ( $this->getWorkEmail() != FALSE ) {
				$primary_email = $this->getWorkEmail();
				if ( $this->getHomeEmail() != FALSE ) {
					$secondary_email = $this->getHomeEmail();
				} else {
					$secondary_email = NULL;
				}
			} else {
				$primary_email = $this->getHomeEmail();
				$secondary_email = NULL;
			}

			$this->setPasswordResetKey( md5( uniqid() ) );
			$this->setPasswordResetDate( time() );
			$this->Save(FALSE);

			if ( $config_vars['other']['force_ssl'] == 1 ) {
				$protocol = 'https';
			} else {
				$protocol = 'http';
			}


			$subject = 'Password Reset requested at '. TTDate::getDate('DATE+TIME', time() ).' from '. $_SERVER['REMOTE_ADDR'];

			$body = '
			<html><body>
			If you did not request your password to be reset, you may ignore this email.
			<br>
			<br>
			If you did request the password for '. $this->getUserName() .' to be reset,
			please click <a href="'.$protocol .'://'.$_SERVER['HTTP_HOST'].Environment::getBaseURL() .'ForgotPassword.php?action=password_reset&key='. $this->getPasswordResetKey().'">here</a>
			</body></html>
			';

			Debug::Text('Emailing Report to: '. $this->getUserName() .' Email: '. $primary_email , __FILE__, __LINE__, __METHOD__,10);
			Debug::Arr($body, 'Email Report', __FILE__, __LINE__, __METHOD__,10);
			//echo "<pre>$body</pre><br>\n";
			mail($primary_email,$subject, $body, "MIME-Version: 1.0\nContent-type: text/html; charset=iso-8859-1\nFrom: \"TimeTrex - Password Reset\"<noreply@timetrex.com>\nCc: ". $secondary_email ."\n");

			return TTLog::addEntry( $this->getId(), 500, 'User Password Reset By: '. $_SERVER['REMOTE_ADDR'], NULL, $this->getTable() );

			return TRUE;
		}

		return FALSE;
	}

	function getPasswordResetKey() {
		if ( isset($this->data['password_reset_key']) ) {
			return $this->data['password_reset_key'];
		}

		return FALSE;
	}
	function setPasswordResetKey($value) {
		$value = trim($value);

		if (	$value == ''
				OR
				$this->Validator->isLength(	$this->passwordresetkey_validator_label,
											$value,
											$this->passwordresetkey_validator_islength_msg,
											1,255) ) {

			$this->data['password_reset_key'] = $value;

			return TRUE;
		}

		return FALSE;
	}

	function getPasswordResetDate() {
		if ( isset($this->data['password_reset_date']) ) {
			return $this->data['password_reset_date'];
		}
	}
	function setPasswordResetDate($epoch) {
		if ( empty($epoch) ) {
			$epoch = NULL;
		}

		if 	(	$epoch == ''
				OR
				$this->Validator->isDate(		$this->passwordresetdate_validator_label,
												$epoch,
												$this->passwordresetdate_validator_isdate_msg) ) {

			$this->data['password_reset_date'] = $epoch;

			return TRUE;
		}

		return FALSE;
	}

	function isInformationComplete() {
		//Make sure the users information is all complete.
		//No longer check for SIN, as employees can't change it anyways.
		if ( $this->getAddress1() == ''
				OR $this->getCity() == ''
				OR $this->getPostalCode() == ''
				OR $this->getHomePhone() == '' ) {
			Debug::text('User Information is NOT Complete: ', __FILE__, __LINE__, __METHOD__, 10);
			return FALSE;
		}

		Debug::text('User Information is Complete: ', __FILE__, __LINE__, __METHOD__, 10);
		return TRUE;
	}

	function Validate() {
		if ( $this->getCompany() == FALSE ) {
			$this->Validator->isTrue(		$this->company_validator_label,
											FALSE,
											$this->company_validator_msg);
		}

		if ( $this->isNew() == TRUE AND ( $this->getPassword() == FALSE OR $this->getPassword() == '' ) ) {
			$this->Validator->isTrue(		$this->password_validator_label,
											FALSE,
											$this->password_validator_length_msg);
		}

		return TRUE;
	}

	function preSave() {
		//$this->encryptPassword();
		if ( $this->getDefaultBranch() == FALSE ) {
			$this->setDefaultBranch(0);
		}
		if ( $this->getDefaultDepartment() == FALSE ) {
			$this->setDefaultDepartment(0);
		}

		if ( $this->getStatus() == FALSE ) {
			$this->setStatus( 10 ); //Active
		}

		//Remember if this is a new user for postSave()
		if ( $this->isNew() ) {
			$this->is_new = TRUE;
		}

		return TRUE;
	}

	function postSave() {
		$this->removeCache( $this->getId() );

		if ( $this->getDeleted() == FALSE AND $this->getPayPeriodSchedule() !== FALSE ) {
			Debug::text('Pay Period Schedule is set...', __FILE__, __LINE__, __METHOD__, 10);

			$ppslf = new PayPeriodScheduleListFactory();
			$ppslf->getByUserId( $this->getId() );
			if ( $ppslf->getRecordCount() > 0 ) {
				$pps_obj = $ppslf->getCurrent();

				if ( $this->getPayPeriodSchedule() == $pps_obj->getId() ) {
					Debug::text('Already assigned to this Pay Period Schedule...', __FILE__, __LINE__, __METHOD__, 10);
				} else {
					Debug::text('Changing Pay Period Schedule...', __FILE__, __LINE__, __METHOD__, 10);

					//Remove user from current schedule.
					$ppsulf = new PayPeriodScheduleUserListFactory();
					$ppsulf->getByPayPeriodScheduleIdAndUserID( $pps_obj->getId(), $this->getId() );
					Debug::text('Record Count: '. $ppsulf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
					if ( $ppsulf->getRecordCount() > 0 ) {
						foreach( $ppsulf as $ppsu_obj ) {
							Debug::text('Deleteing from Pay Period Schedule: '. $ppsu_obj->getPayPeriodSchedule(), __FILE__, __LINE__, __METHOD__, 10);
							$ppsu_obj->Delete();
						}
					}
				}
			} else {
				Debug::text('Not assigned to ANY Pay Period Schedule...', __FILE__, __LINE__, __METHOD__, 10);
			}

			if ( $this->getPayPeriodSchedule() !== FALSE ) {
				//Add to new pay period schedule
				$ppsuf = new PayPeriodScheduleUserFactory();
				$ppsuf->setPayPeriodSchedule( $this->getPayPeriodSchedule() );
				$ppsuf->setUser( $this->getID() );

				if ( $ppsuf->isValid() ) {
					$ppsuf->Save();
				}
			}
		}

		if ( $this->getDeleted() == FALSE AND $this->getPolicyGroup() !== FALSE ) {
			Debug::text('Policy Group is set...', __FILE__, __LINE__, __METHOD__, 10);

			$pglf = new PolicyGroupListFactory();
			$pglf->getByUserIds( $this->getId() );
			if ( $pglf->getRecordCount() > 0 ) {
				$pg_obj = $pglf->getCurrent();

				if ( $this->getPolicyGroup() == $pg_obj->getId() ) {
					Debug::text('Already assigned to this Policy Group...', __FILE__, __LINE__, __METHOD__, 10);
				} else {
					Debug::text('Changing Policy Group...', __FILE__, __LINE__, __METHOD__, 10);

					//Remove user from current schedule.
					$pgulf = new PolicyGroupUserListFactory();
					$pgulf->getByPolicyGroupIdAndUserId( $pg_obj->getId(), $this->getId() );
					Debug::text('Record Count: '. $pgulf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
					if ( $pgulf->getRecordCount() > 0 ) {
						foreach( $pgulf as $pgu_obj ) {
							Debug::text('Deleteing from Policy Group: '. $pgu_obj->getPolicyGroup(), __FILE__, __LINE__, __METHOD__, 10);
							$pgu_obj->Delete();
						}
					}
				}
			} else {
				Debug::text('Not assigned to ANY Policy Group...', __FILE__, __LINE__, __METHOD__, 10);
			}

			if ( $this->getPolicyGroup() !== FALSE ) {
				//Add to new policy group
				$pguf = new PolicyGroupUserFactory();
				$pguf->setPolicyGroup( $this->getPolicyGroup() );
				$pguf->setUser( $this->getID() );

				if ( $pguf->isValid() ) {
					$pguf->Save();
				}
			}

		}

		if ( isset($this->is_new) AND $this->is_new == TRUE ) {
			$udlf = new UserDefaultListFactory();
			$udlf->getByCompanyId( $this->getCompany() );
			if ( $udlf->getRecordCount() > 0 ) {
				Debug::Text('Using User Defaults', __FILE__, __LINE__, __METHOD__,10);
				$udf_obj = $udlf->getCurrent();

				Debug::text('Inserting Default Deductions...', __FILE__, __LINE__, __METHOD__, 10);

				$company_deduction_ids = $udf_obj->getCompanyDeduction();
				if ( is_array($company_deduction_ids) AND count($company_deduction_ids) > 0 ) {
					foreach( $company_deduction_ids as $company_deduction_id ) {
						$udf = new UserDeductionFactory();
						$udf->setUser( $this->getId() );
						$udf->setCompanyDeduction( $company_deduction_id );
						if ( $udf->isValid() ) {
							$udf->Save();
						}
					}
				}
				unset($company_deduction_ids, $company_deduction_id, $udf);

				Debug::text('Inserting Default Prefs...', __FILE__, __LINE__, __METHOD__, 10);
				$upf = new UserPreferenceFactory();
				$upf->setUser( $this->getId() );
				$upf->setDateFormat( $udf_obj->getDateFormat() );
				$upf->setTimeFormat( $udf_obj->getTimeFormat() );
				$upf->setTimeUnitFormat( $udf_obj->getTimeUnitFormat() );
				$upf->setTimeZone( $udf_obj->getTimeZone() );
				$upf->setItemsPerPage( $udf_obj->getItemsPerPage() );
				$upf->setStartWeekDay( $udf_obj->getStartWeekDay() );

				if ( $upf->isValid() ) {
					$upf->Save();
				}
			}

		}

		return TRUE;
	}

	function setObjectFromArray( $data ) {
		if ( isset($data['company_id']) ) {
			$this->setCompany($data['company_id']);
		}

		if ( isset($data['id']) ) {
			$this->setId($data['id']);
		}

		if ( isset($data['status_id']) ) {
			$this->setStatus($data['status_id']);
		}

		if ( isset($data['user_name']) ) {
			$this->setUserName($data['user_name']);
		}

		if ( isset($data['password']) ) {
			$this->setPassword($data['password']);
		}

		if ( isset($data['phone_id']) ) {
			$this->setPhoneId($data['phone_id']);
		}

		if ( isset($data['phone_password']) ) {
			$this->setPhonePassword($data['phone_password']);
		}

		if ( isset($data['ibutton_id']) ) {
			$this->setIButtonId($data['ibutton_id']);
		}

		if ( isset($data['employee_number']) ) {
			$this->setEmployeeNumber($data['employee_number']);
		}

		if ( isset($data['title_id']) ) {
			$this->setTitle($data['title_id']);
		}

		if ( isset($data['default_branch_id']) ) {
			$this->setDefaultBranch($data['default_branch_id']);
		}

		if ( isset($data['default_department_id']) ) {
			$this->setDefaultDepartment($data['default_department_id']);
		}

		if ( isset($data['first_name']) ) {
			$this->setFirstName($data['first_name']);
		}

		if ( isset($data['last_name']) ) {
			$this->setLastName($data['last_name']);
		}

		if ( isset($data['middle_name']) ) {
			$this->setMiddleName($data['middle_name']);
		}

		if ( isset($data['sex_id']) ) {
			$this->setSex($data['sex_id']);
		}

		if ( isset($data['address1']) ) {
			$this->setAddress1($data['address1']);
		}

		if ( isset($data['address2']) ) {
			$this->setAddress2($data['address2']);
		}

		if ( isset($data['city']) ) {
			$this->setCity($data['city']);
		}

		if ( isset($data['country']) ) {
			$this->setCountry($data['country']);
		}

		if ( isset($data['province']) ) {
			$this->setProvince($data['province']);
		}

		if ( isset($data['postal_code']) ) {
			$this->setPostalCode($data['postal_code']);
		}

		if ( isset($data['work_phone']) ) {
			$this->setWorkPhone($data['work_phone']);
		}

		if ( isset($data['work_phone_ext']) ) {
			$this->setWorkPhoneExt($data['work_phone_ext']);
		}

		if ( isset($data['home_phone']) ) {
			$this->setHomePhone($data['home_phone']);
		}

		if ( isset($data['mobile_phone']) ) {
			$this->setMobilePhone($data['mobile_phone']);
		}

		if ( isset($data['fax_phone']) ) {
			$this->setFaxPhone($data['fax_phone']);
		}

		if ( isset($data['home_email']) ) {
			$this->setHomeEmail($data['home_email']);
		}

		if ( isset($data['work_email']) ) {
			$this->setWorkEmail($data['work_email']);
		}

		if ( isset($data['birth_date']) ) {
			$this->setBirthDate($data['birth_date']);
		}

		if ( isset($data['hire_date']) ) {
			$this->setHireDate($data['hire_date']);
		}

		if ( isset($data['termination_date']) ) {
			$this->setTerminationDate($data['termination_date']);
		}

		if ( isset($data['sin']) ) {
			$this->setSin($data['sin']);
		}

		if ( isset($data['other_id1']) ) {
			$this->setOtherID1($data['other_id1']);
		}
		if ( isset($data['other_id2']) ) {
			$this->setOtherID2($data['other_id2']);
		}
		if ( isset($data['other_id3']) ) {
			$this->setOtherID3($data['other_id3']);
		}
		if ( isset($data['other_id4']) ) {
			$this->setOtherID4($data['other_id4']);
		}
		if ( isset($data['other_id5']) ) {
			$this->setOtherID5($data['other_id5']);
		}

		if ( isset($data['note']) ) {
			$this->setNote($data['note']);
		}

		if ( isset($data['deleted']) ) {
			$this->setDeleted($data['deleted']);
		}

		return TRUE;
	}

	function getObjectAsArray() {
		$data = array(
						'id' => $this->getId(),
						'status_id' => $this->getStatus(),
		                'company_id' => $this->getCompany(),
						'user_name' => $this->getUserName(),
                        //'password' => $this->getPassword(),
						'phone_id' => $this->getPhoneId(),
						'phone_password' => $this->getPhonePassword(),
                        'ibutton_id' => $this->getIButtonId(),
						'employee_number' => $this->getEmployeeNumber(),
                        'title_id' => $this->getTitle(),
                        'default_branch_id' => $this->getDefaultBranch(),
                        'default_department_id' => $this->getDefaultDepartment(),
						'first_name' => $this->getFirstName(),
						'last_name' => $this->getLastName(),
		                'middle_name' => $this->getMiddleName(),
						'sex_id' => $this->getSex(),
						'address1' => $this->getAddress1(),
						'address2' => $this->getAddress2(),
						'city' => $this->getCity(),
                        'country' => $this->getCountry(),
                        'province' => $this->getProvince(),
		                'postal_code' => $this->getPostalCode(),
						'work_phone' => $this->getWorkPhone(),
						'work_phone_ext' => $this->getWorkPhoneExt(),
						'home_phone' => $this->getHomePhone(),
						'mobile_phone' => $this->getMobilePhone(),
						'fax_phone' => $this->getFaxPhone(),
						'home_email' => $this->getHomeEmail(),
						'work_email' => $this->getWorkEmail(),
                        'birth_date' => $this->getBirthDate(),
						'hire_date' => $this->getHireDate(),
						'termination_date' => $this->getTerminationDate(),
                        'sin' => $this->getSin(),
                        'other_id1' => $this->getOtherID1(),
                        'other_id2' => $this->getOtherID2(),
                        'other_id3' => $this->getOtherID3(),
                        'other_id4' => $this->getOtherID4(),
                        'other_id5' => $this->getOtherID5(),
                        'note' => $this->getNote(),
						'deleted' => $this->getDeleted(),
					);
		return $data;
	}

	function addLog( $log_action ) {
		return TTLog::addEntry( $this->getId(), $log_action, 'User Information', NULL, $this->getTable() );
	}

}
?>
