<?php
/*********************************************************************************
 * The contents of this file are subject to the TimeTrex Public License Version
 * 1.1.0 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by TimeTrex" logo and
 *    (ii) the TimeTrex copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: TimeTrex Open Source
 * The Initial Developer of the Original Code is TimeTrex Payroll Services
 * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
 * All Rights Reserved.
 *
 ********************************************************************************/
/*
 * $Revision: 417 $
 * $Id: AuthorizationList.php 417 2006-12-06 22:58:53Z ipso $
 * $Date: 2006-12-06 14:58:53 -0800 (Wed, 06 Dec 2006) $
 */
require_once('../../includes/global.inc.php');
require_once(Environment::getBasePath() .'includes/Interface.inc.php');

if ( !$permission->Check('authorization','enabled')
		OR !( $permission->Check('authorization','view') ) ) {

	$permission->Redirect( FALSE ); //Redirect
}

//Debug::setVerbosity(11);

$title = 'Authorization List';
$smarty->assign('title', $title );
BreadCrumb::setCrumb($title);

/*
 * Get FORM variables
 */
extract	(FormVariables::GetVariables(
										array	(
												'action',
												'page',
												'sort_column',
												'sort_order',
												'ids',
												'level',
												'selected_levels'
												) ) );

switch (strtolower($action)) {
	case 'submit':
		Debug::Text('Submit!', __FILE__, __LINE__, __METHOD__,10);

	default:
		Debug::Text('Level: '. $level, __FILE__, __LINE__, __METHOD__,10);

		$ulf = new UserListFactory();
		$hlf = new HierarchyListFactory();
		$hotlf = new HierarchyObjectTypeListFactory();

		if ( $permission->Check('request','authorize') ) {
			//Debug::Text('Selected Level: '. $selected_levels['default_schedule'], __FILE__, __LINE__, __METHOD__,10);

			//Get Hierarchy Control ID
			$request_hierarchy_id = $hotlf->getByCompanyIdAndObjectTypeId( $current_company->getId(), 50 )->getCurrent()->getHierarchyControl();
			Debug::Text('Request Hierarchy ID: '. $request_hierarchy_id, __FILE__, __LINE__, __METHOD__,10);

			//Get all levels below us.
			$request_levels = $hlf->getLevelsByHierarchyControlIdAndUserId( $request_hierarchy_id,  $current_user->getId() );
			Debug::Arr( $request_levels, 'Request Levels', __FILE__, __LINE__, __METHOD__,10);

			if ( isset($selected_levels['request']) AND in_array( $selected_levels['request'], array_keys($request_levels) ) ) {
				$request_user_id = $request_levels[$selected_levels['request']];
				Debug::Text(' Switching Levels... Using UserID: '. $request_user_id, __FILE__, __LINE__, __METHOD__,10);
			} else {
				$request_user_id = $current_user->getId();
			}

			$request_node_data = $hlf->getByHierarchyControlIdAndUserId( $request_hierarchy_id, $request_user_id );

			//Get current level IDs
			$request_current_level_user_ids = $hlf->getCurrentLevelIdArrayByHierarchyControlIdAndUserId($request_hierarchy_id, $request_user_id );
			Debug::Arr( $request_current_level_user_ids, 'Request Current Level Ids', __FILE__, __LINE__, __METHOD__,10);

			//Get Parents
			$request_parent_level_user_ids = $hlf->getParentLevelIdArrayByHierarchyControlIdAndUserId($request_hierarchy_id, $request_user_id );
			Debug::Arr( $request_parent_level_user_ids, 'Request Parent Level Ids', __FILE__, __LINE__, __METHOD__,10);

			//Get Children
			$request_child_level_user_ids = $hlf->getChildLevelIdArrayByHierarchyControlIdAndUserId($request_hierarchy_id, $request_user_id );
			Debug::Arr( $request_child_level_user_ids, 'Request Child Level Ids', __FILE__, __LINE__, __METHOD__,10);

			if ( !( $request_current_level_user_ids === FALSE
					AND $request_parent_level_user_ids === FALSE
					AND $request_child_level_user_ids === FALSE ) ) {

				$rlf = new RequestListFactory();
				$rlf->getByUserIdListAndStatusAndNotAuthorized($request_child_level_user_ids, 30, $request_parent_level_user_ids, $request_current_level_user_ids );

				$status_options = $rlf->getOptions('status');
				$type_options = $rlf->getOptions('type');

				foreach( $rlf as $r_obj) {
					//Grab authorizations for this object.

					//Debug::Text('Request User ID: '. $r_obj->getId(), __FILE__, __LINE__, __METHOD__,10);
					//$r_user_data = $ulf->getById( $r_obj->getUser() )->getCurrent() ;

					$requests[] = array(
											'id' => $r_obj->getId(),
											'user_date_id' => $r_obj->getId(),
											'user_id' => $r_obj->getUserDateObject()->getUser(),
											'user_full_name' => $r_obj->getUserDateObject()->getUserObject()->getFullName(),
											'date_stamp' => $r_obj->getUserDateObject()->getDateStamp(),
											'type_id' => $r_obj->getType(),
											'type' => $type_options[$r_obj->getType()],
											'status_id' => $r_obj->getStatus(),
											'status' => $status_options[$r_obj->getStatus()]
														);
				}
				$smarty->assign_by_ref('requests', $requests);

				if ( isset($request_levels) AND is_array($request_levels) ) {
					$smarty->assign_by_ref('request_levels', array_keys( $request_levels ) );
					if ( isset($selected_levels['request']) AND in_array( $selected_levels['request'], array_keys($request_levels) ) ) {
						$selected_request_level = $selected_levels['request'];
					} else {
						$selected_request_level = $request_node_data['level'];
					}
					$smarty->assign_by_ref('selected_request_level', $selected_request_level);
				}
			}
		}

/*
		if ( $permission->Check('default_schedule','authorize') ) {
			//Debug::Text('Selected Level: '. $selected_levels['default_schedule'], __FILE__, __LINE__, __METHOD__,10);

			//Get Hierarchy Control ID
			$default_schedule_hierarchy_id = $hotlf->getByCompanyIdAndObjectTypeId( $current_company->getId(), 10 )->getCurrent()->getHierarchyControl();
			Debug::Text('Default Schedule Hierarchy ID: '. $default_schedule_hierarchy_id, __FILE__, __LINE__, __METHOD__,10);

			//Get all levels below us.
			$default_schedule_levels = $hlf->getLevelsByHierarchyControlIdAndUserId( $default_schedule_hierarchy_id,  $current_user->getId() );
			Debug::Arr( $default_schedule_levels, 'Default Schedule Levels', __FILE__, __LINE__, __METHOD__,10);

			if ( isset($selected_levels['default_schedule']) AND in_array( $selected_levels['default_schedule'], array_keys($default_schedule_levels) ) ) {
				$default_schedule_user_id = $default_schedule_levels[$selected_levels['default_schedule']];
				Debug::Text(' Switching Levels... Using UserID: '. $default_schedule_user_id, __FILE__, __LINE__, __METHOD__,10);
			} else {
				$default_schedule_user_id = $current_user->getId();
			}

			$default_schedule_node_data = $hlf->getByHierarchyControlIdAndUserId( $default_schedule_hierarchy_id, $default_schedule_user_id );

			//Get current level IDs
			$default_schedule_current_level_user_ids = $hlf->getCurrentLevelIdArrayByHierarchyControlIdAndUserId($default_schedule_hierarchy_id, $default_schedule_user_id );
			Debug::Arr( $default_schedule_current_level_user_ids, 'Default Schedule Current Level Ids', __FILE__, __LINE__, __METHOD__,10);

			//Get Parents
			$default_schedule_parent_level_user_ids = $hlf->getParentLevelIdArrayByHierarchyControlIdAndUserId($default_schedule_hierarchy_id, $default_schedule_user_id );
			Debug::Arr( $default_schedule_parent_level_user_ids, 'Default Schedule Parent Level Ids', __FILE__, __LINE__, __METHOD__,10);

			//Get Children
			$default_schedule_child_level_user_ids = $hlf->getChildLevelIdArrayByHierarchyControlIdAndUserId($default_schedule_hierarchy_id, $default_schedule_user_id );
			Debug::Arr( $default_schedule_child_level_user_ids, 'Default Schedule Child Level Ids', __FILE__, __LINE__, __METHOD__,10);

			if ( !( $default_schedule_current_level_user_ids === FALSE
					AND $default_schedule_parent_level_user_ids === FALSE
					AND $default_schedule_child_level_user_ids === FALSE ) ) {

				$dsculf = new DefaultScheduleControlUserListFactory();
				//$dsculf->getByUserIdListAndStatusAndNotAuthorized($default_schedule_current_level_user_ids, 30, $default_schedule_parent_level_user_ids, $default_schedule_current_level_user_ids, NULL, NULL, NULL, array('a.created_date' => 'asc') );
				$dsculf->getByUserIdListAndStatusAndNotAuthorized($default_schedule_child_level_user_ids, 30, $default_schedule_parent_level_user_ids, $default_schedule_current_level_user_ids, NULL, NULL, NULL, array('a.created_date' => 'asc') );
				foreach( $dsculf as $default_schedule_control_user) {
					//Grab authorizations for this object.

					Debug::Text('Default Schedule Control User ID: '. $default_schedule_control_user->getId(), __FILE__, __LINE__, __METHOD__,10);
					$default_schedule_control_user_data = $ulf->getById( $default_schedule_control_user->getUser() )->getCurrent() ;

					$default_schedule_controls[] = array(
															'id' => $default_schedule_control_user->getId(),
															'user_id' => $default_schedule_control_user->getUser(),
															'user_full_name' => $default_schedule_control_user_data->getFullName(),
															'name' => $default_schedule_control_user->getDefaultScheduleControlObject()->getName(),
															'description' => $default_schedule_control_user->getDefaultScheduleControlObject()->getDescription()
														);
				}
				$smarty->assign_by_ref('default_schedule_controls', $default_schedule_controls);

				if ( isset($default_schedule_levels) AND is_array($default_schedule_levels) ) {
					$smarty->assign_by_ref('default_schedule_levels', array_keys( $default_schedule_levels ) );
					if ( isset($selected_levels['default_schedule']) AND in_array( $selected_levels['default_schedule'], array_keys($default_schedule_levels) ) ) {
						$selected_default_schedule_level = $selected_levels['default_schedule'];
					} else {
						$selected_default_schedule_level = $default_schedule_node_data['level'];
					}
					$smarty->assign_by_ref('selected_default_schedule_level', $selected_default_schedule_level);
				}
			}
		}

		if ( $permission->Check('schedule_amendment','authorize') ) {
			//Debug::Text('Selected Level: '. $selected_levels['schedule_amendment'], __FILE__, __LINE__, __METHOD__,10);

			//Get Hierarchy Control ID
			$schedule_amendment_hierarchy_id = $hotlf->getByCompanyIdAndObjectTypeId( $current_company->getId(), 20 )->getCurrent()->getHierarchyControl();
			Debug::Text('Schedule Amendment Hierarchy ID: '. $schedule_amendment_hierarchy_id, __FILE__, __LINE__, __METHOD__,10);

			//Get all levels below us.
			$schedule_amendment_levels = $hlf->getLevelsByHierarchyControlIdAndUserId( $schedule_amendment_hierarchy_id,  $current_user->getId() );
			Debug::Arr( $schedule_amendment_levels, 'Schedule Amendment Levels', __FILE__, __LINE__, __METHOD__,10);

			if ( isset($selected_levels['schedule_amendment']) AND in_array( $selected_levels['schedule_amendment'], array_keys($schedule_amendment_levels) ) ) {
				$schedule_amendment_user_id = $schedule_amendment_levels[$selected_levels['schedule_amendment']];
				Debug::Text(' Switching Levels... Using UserID: '. $schedule_amendment_user_id, __FILE__, __LINE__, __METHOD__,10);
			} else {
				$schedule_amendment_user_id = $current_user->getId();
			}

			$schedule_amendment_node_data = $hlf->getByHierarchyControlIdAndUserId( $schedule_amendment_hierarchy_id, $schedule_amendment_user_id );

			//Get current level IDs
			$schedule_amendment_current_level_user_ids = $hlf->getCurrentLevelIdArrayByHierarchyControlIdAndUserId($schedule_amendment_hierarchy_id, $schedule_amendment_user_id );
			Debug::Arr( $schedule_amendment_current_level_user_ids, 'Schedule Amendment Current Level Ids', __FILE__, __LINE__, __METHOD__,10);

			//Get Parents
			$schedule_amendment_parent_level_user_ids = $hlf->getParentLevelIdArrayByHierarchyControlIdAndUserId($schedule_amendment_hierarchy_id, $schedule_amendment_user_id );
			Debug::Arr( $schedule_amendment_parent_level_user_ids, 'Schedule Amendment Parent Level Ids', __FILE__, __LINE__, __METHOD__,10);

			//Get Children
			$schedule_amendment_child_level_user_ids = $hlf->getChildLevelIdArrayByHierarchyControlIdAndUserId($schedule_amendment_hierarchy_id, $schedule_amendment_user_id );
			Debug::Arr( $schedule_amendment_child_level_user_ids, 'Schedule Amendment Child Level Ids', __FILE__, __LINE__, __METHOD__,10);

			if ( !( $schedule_amendment_current_level_user_ids === FALSE
					AND $schedule_amendment_parent_level_user_ids === FALSE
					AND $schedule_amendment_child_level_user_ids === FALSE ) ) {

				$saclf = new ScheduleAmendmentControlListFactory();
				$saclf->getByUserIdListAndStatusAndNotAuthorized($schedule_amendment_child_level_user_ids, 30, $schedule_amendment_parent_level_user_ids, $schedule_amendment_current_level_user_ids,NULL, NULL, NULL, array('a.created_date' => 'asc') );
				foreach( $saclf as $schedule_amendment_control) {
					//Grab authorizations for this object.

					Debug::Text('Schedule Amendment Control ID: '. $schedule_amendment_control->getId(), __FILE__, __LINE__, __METHOD__,10);
					$schedule_amendment_control_user_data = $ulf->getById( $schedule_amendment_control->getUser() )->getCurrent() ;

					$schedule_amendment_controls[] = array(
															'id' => $schedule_amendment_control->getId(),
															'user_id' => $schedule_amendment_control->getUser(),
															'user_full_name' => $schedule_amendment_control_user_data->getFullName(),
															'name' => $schedule_amendment_control->getName(),
															'description' => $schedule_amendment_control->getDescription()
														);
				}
				$smarty->assign_by_ref('schedule_amendment_controls', $schedule_amendment_controls);
				$smarty->assign_by_ref('schedule_amendment_levels', array_keys($schedule_amendment_levels) );
				if ( isset($selected_levels['schedule_amendment']) AND in_array( $selected_levels['schedule_amendment'], array_keys($schedule_amendment_levels) ) ) {
					$selected_schedule_amendment_level = $selected_levels['schedule_amendment'];
				} else {
					$selected_schedule_amendment_level = $schedule_amendment_node_data['level'];
				}
				$smarty->assign_by_ref('selected_schedule_amendment_level', $selected_schedule_amendment_level);
			}
		}

		if ( $permission->Check('shift_amendment','authorize') ) {
			//Debug::Text('Selected Level: '. $selected_levels['schedule_amendment'], __FILE__, __LINE__, __METHOD__,10);

			//Get Hierarchy Control ID
			$shift_amendment_hierarchy_id = $hotlf->getByCompanyIdAndObjectTypeId( $current_company->getId(), 30 )->getCurrent()->getHierarchyControl();
			Debug::Text('Shift Amendment Hierarchy ID: '. $shift_amendment_hierarchy_id, __FILE__, __LINE__, __METHOD__,10);

			//Get all levels below us.
			$shift_amendment_levels = $hlf->getLevelsByHierarchyControlIdAndUserId( $shift_amendment_hierarchy_id,  $current_user->getId() );
			Debug::Arr( $shift_amendment_levels, 'Shift Amendment Levels', __FILE__, __LINE__, __METHOD__,10);

			if ( isset($selected_levels['shift_amendment']) AND in_array( $selected_levels['shift_amendment'], array_keys($shift_amendment_levels) ) ) {
				$shift_amendment_user_id = $shift_amendment_levels[$selected_levels['shift_amendment']];
				Debug::Text(' Switching Levels... Using UserID: '. $shift_amendment_user_id, __FILE__, __LINE__, __METHOD__,10);
			} else {
				$shift_amendment_user_id = $current_user->getId();
			}

			$shift_amendment_node_data = $hlf->getByHierarchyControlIdAndUserId( $shift_amendment_hierarchy_id, $shift_amendment_user_id );

			//Get current level IDs
			$shift_amendment_current_level_user_ids = $hlf->getCurrentLevelIdArrayByHierarchyControlIdAndUserId($shift_amendment_hierarchy_id, $shift_amendment_user_id );
			Debug::Arr( $shift_amendment_current_level_user_ids, 'Shift Amendment Current Level Ids', __FILE__, __LINE__, __METHOD__,10);

			//Get Parents
			$shift_amendment_parent_level_user_ids = $hlf->getParentLevelIdArrayByHierarchyControlIdAndUserId($shift_amendment_hierarchy_id, $shift_amendment_user_id );
			Debug::Arr( $shift_amendment_parent_level_user_ids, 'Shift Amendment Parent Level Ids', __FILE__, __LINE__, __METHOD__,10);

			//Get Children
			$shift_amendment_child_level_user_ids = $hlf->getChildLevelIdArrayByHierarchyControlIdAndUserId($shift_amendment_hierarchy_id, $shift_amendment_user_id );
			Debug::Arr( $shift_amendment_child_level_user_ids, 'Shift Amendment Child Level Ids', __FILE__, __LINE__, __METHOD__,10);

			if ( !( $shift_amendment_current_level_user_ids === FALSE
					AND $shift_amendment_parent_level_user_ids === FALSE
					AND $shift_amendment_child_level_user_ids === FALSE ) ) {

				$salf = new ShiftAmendmentListFactory();
				$salf->getByUserIdListAndStatusAndNotAuthorized($shift_amendment_child_level_user_ids, 30, $shift_amendment_parent_level_user_ids, $shift_amendment_current_level_user_ids );
				//$id, $status, $parent_level_user_ids, $current_user_id, $limit = NULL, $page = NULL, $where = NULL, $order = NULL
				foreach( $salf as $shift_amendment ) {

					$shift_amendment_user_data = $ulf->getById( $shift_amendment->getScheduleShiftObject()->getUser() )->getCurrent() ;

					if ( $shift_amendment->getStartDate() == '' ) {
						$name = '[ '. TTDate::getDate('DATE+TIME', $shift_amendment->getScheduleShiftObject()->getStartDate() ).' ]';
						$description = '[ '. TTDate::getDate('DATE+TIME', $shift_amendment->getScheduleShiftObject()->getStartDate() ).' - '. TTDate::getDate('DATE+TIME', $shift_amendment->getScheduleShiftObject()->getEndDate() ).' ]';
					} else {
						$name = TTDate::getDate('DATE+TIME', $shift_amendment->getStartDate() );
						$description = TTDate::getDate('DATE+TIME', $shift_amendment->getStartDate() ).' - '. TTDate::getDate('DATE+TIME', $shift_amendment->getEndDate() );
					}

					$shift_amendments[] = array(
															'id' => $shift_amendment->getId(),
															'user_id' => $shift_amendment_user_data->getId(),
															'user_full_name' => $shift_amendment_user_data->getFullName(),
															'name' => $name,
															'description' => $description
														);
					unset($name, $description);

				}

				$smarty->assign_by_ref('shift_amendments', $shift_amendments);
				$smarty->assign_by_ref('shift_amendment_levels', array_keys($shift_amendment_levels) );
				if ( isset($selected_levels['shift_amendment']) AND in_array( $selected_levels['shift_amendment'], array_keys($shift_amendment_levels) ) ) {
					$selected_shift_amendment_level = $selected_levels['shift_amendment'];
				} else {
					$selected_shift_amendment_level = $shift_amendment_node_data['level'];
				}
				$smarty->assign_by_ref('selected_shift_amendment_level', $selected_shift_amendment_level);
			}
		}
*/

		$smarty->assign_by_ref('selected_levels', $selected_levels );

		$smarty->assign_by_ref('sort_column', $sort_column );
		$smarty->assign_by_ref('sort_order', $sort_order );

		break;
}
$smarty->display('authorization/AuthorizationList.tpl');
?>