<?php
/*********************************************************************************
 * The contents of this file are subject to the TimeTrex Public License Version
 * 1.1.0 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by TimeTrex" logo and
 *    (ii) the TimeTrex copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: TimeTrex Open Source
 * The Initial Developer of the Original Code is TimeTrex Payroll Services
 * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
 * All Rights Reserved.
 *
 ********************************************************************************/
/*
 * $Revision: 417 $
 * $Id: EditExceptionPolicyControl.php 417 2006-12-06 22:58:53Z ipso $
 * $Date: 2006-12-06 14:58:53 -0800 (Wed, 06 Dec 2006) $
 */
require_once('../../includes/global.inc.php');
require_once(Environment::getBasePath() .'includes/Interface.inc.php');

//Debug::setVerbosity(11);

if ( !$permission->Check('exception_policy','enabled')
		OR !( $permission->Check('exception_policy','edit') OR $permission->Check('exception_policy','edit_own') ) ) {

	$permission->Redirect( FALSE ); //Redirect

}

$title = 'Edit Exception Policy';
$smarty->assign('title', $title);

/*
 * Get FORM variables
 */
extract	(FormVariables::GetVariables(
										array	(
												'action',
												'id',
												'data'
												) ) );

if ( isset($data['exceptions'])) {
	foreach( $data['exceptions'] as $code => $exception ) {

		if ( isset($exception['grace']) AND $exception['grace'] != '') {
			Debug::Text('Grace: '. $exception['grace'] , __FILE__, __LINE__, __METHOD__,10);
			$data['exceptions'][$code]['grace'] = TTDate::parseTimeUnit( $exception['grace'] );
		}
		if ( isset($exception['watch_window']) AND $exception['watch_window'] != '') {
			$data['exceptions'][$code]['watch_window'] = TTDate::parseTimeUnit( $exception['watch_window'] );
		}
	}
}

$epf = new ExceptionPolicyFactory();
$epcf = new ExceptionPolicyControlFactory();

$action = strtolower($action);
switch ($action) {
	case 'submit':
		Debug::Text('Submit!', __FILE__, __LINE__, __METHOD__,10);

		$epcf->setId( $data['id'] );
		$epcf->setCompany( $current_company->getId() );
		$epcf->setName( $data['name'] );

		if ( $epcf->isValid() ) {
			$epc_id = $epcf->Save();

			Debug::Text('aException Policy Control ID: '. $epc_id , __FILE__, __LINE__, __METHOD__,10);

			if ( $epc_id === TRUE ) {
				$epc_id = $data['id'];
			}

			Debug::Text('bException Policy Control ID: '. $epc_id , __FILE__, __LINE__, __METHOD__,10);

			if ( count($data['exceptions']) > 0 ) {

				foreach ($data['exceptions'] as $code => $exception_data) {
					Debug::Text('Looping Code: '. $code .' ID: '. $exception_data['id'], __FILE__, __LINE__, __METHOD__,10);

					if ( $exception_data['id'] != '' AND $exception_data['id'] > 0 ) {
						$epf->setId( $exception_data['id'] );
					}
					$epf->setExceptionPolicyControl( $epc_id );
					if ( isset($exception_data['active'])  ) {
						$epf->setActive( TRUE );
					} else {
						$epf->setActive( FALSE );
					}
					$epf->setType( $code );
					$epf->setSeverity( $exception_data['severity_id'] );
					if ( isset($exception_data['demerit']) AND $exception_data['demerit'] != '') {
						$epf->setDemerit( $exception_data['demerit'] );
					}
					if ( isset($exception_data['grace']) AND $exception_data['grace'] != '' ) {
						$epf->setGrace( $exception_data['grace'] );
					}
					if ( isset($exception_data['watch_window']) AND $exception_data['watch_window'] != '' ) {
						$epf->setWatchWindow( $exception_data['watch_window'] );
					}
					if ( $epf->isValid() ) {
						$epf->Save();
					}


				}

			}

			Redirect::Page( URLBuilder::getURL( NULL, 'ExceptionPolicyControlList.php') );

			break;
		}

	default:
		$type_options = $epf->getOptions('type');

		if ( isset($id) ) {
			BreadCrumb::setCrumb($title);

			$epclf = new ExceptionPolicyControlListFactory();
			$epclf->getById($id);

			foreach ($epclf as $epc_obj) {
				//Debug::Arr($station,'Department', __FILE__, __LINE__, __METHOD__,10);

				$eplf = new ExceptionPolicyListFactory();
				$eplf->getByExceptionPolicyControlID( $id );
				if ( $eplf->getRecordCount() > 0 ) {
					foreach( $eplf as $ep_obj ) {
						$exceptions[$ep_obj->getType()] = array(
																'id' => $ep_obj->getId(),
																'active' => $ep_obj->getActive(),
																'type_id' => $ep_obj->getType(),
																'name' => $type_options[$ep_obj->getType()],
																'severity_id' => $ep_obj->getSeverity(),
																'demerit' => $ep_obj->getDemerit(),
																'grace' => (int)$ep_obj->getGrace(),
																'is_enabled_grace' => $ep_obj->isEnabledGrace( $ep_obj->getType() ),
																'watch_window' => (int)$ep_obj->getWatchWindow(),
																'is_enabled_watch_window' => $ep_obj->isEnabledWatchWindow( $ep_obj->getType() )
																);

					}
				} else {
					$exceptions = array();
				}

				//Populate default values.
				foreach( $type_options as $type_id => $name ) {
					Debug::Text('Looping for default values', __FILE__, __LINE__, __METHOD__,10);
					if ( !isset( $exceptions[$type_id] ) ) {
						Debug::Text('setting default values, Type: '. $type_id, __FILE__, __LINE__, __METHOD__,10);
						$exceptions[$type_id] = array(
												'id' => -1,
												'type_id' => $type_id,
												'name' => $type_options[$type_id],
												'demerit' => 0,
												'grace' => 0,
												'is_enabled_grace' => $epf->isEnabledGrace( $type_id ),
												'watch_window' => 0,
												'is_enabled_watch_window' => $epf->isEnabledWatchWindow( $type_id )
												);
					}
				}

				$data = array(
									'id' => $epc_obj->getId(),
									'name' => $epc_obj->getName(),
									'exceptions' => $exceptions,
									'created_date' => $epc_obj->getCreatedDate(),
									'created_by' => $epc_obj->getCreatedBy(),
									'updated_date' => $epc_obj->getUpdatedDate(),
									'updated_by' => $epc_obj->getUpdatedBy(),
									'deleted_date' => $epc_obj->getDeletedDate(),
									'deleted_by' => $epc_obj->getDeletedBy()
								);
				//Grab exceptions that are already set.

			}
		} elseif ( $action != 'submit' ) {
			foreach( $type_options as $type_id => $name ) {
				Debug::Text('Looping for default values', __FILE__, __LINE__, __METHOD__,10);
				if ( !isset( $exceptions[$type_id] ) ) {
					Debug::Text('setting default values, Type: '. $type_id, __FILE__, __LINE__, __METHOD__,10);
					$exceptions[$type_id] = array(
											'id' => -1,
											'type_id' => $type_id,
											'name' => $type_options[$type_id],
											'demerit' => 0,
											'grace' => 0,
											'is_enabled_grace' => $epf->isEnabledGrace( $type_id ),
											'watch_window' => 0,
											'is_enabled_watch_window' => $epf->isEnabledWatchWindow( $type_id )
											);
				}
			}

			$data = array( 'exceptions' => $exceptions );

		}

//		var_dump($data);


		//Select box options;
		$data['severity_options'] = $epf->getOptions('severity');

		$smarty->assign_by_ref('data', $data);
		//$smarty->assign_by_ref('exceptions', $exceptions);
		break;
}

$smarty->assign_by_ref('epf', $epf);
$smarty->assign_by_ref('epcf', $epcf);

$smarty->display('policy/EditExceptionPolicyControl.tpl');
?>