<?php
/*********************************************************************************
 * The contents of this file are subject to the TimeTrex Public License Version
 * 1.1.0 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by TimeTrex" logo and
 *    (ii) the TimeTrex copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: TimeTrex Open Source
 * The Initial Developer of the Original Code is TimeTrex Payroll Services
 * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
 * All Rights Reserved.
 *
 ********************************************************************************/
/*
 * $Revision: 417 $
 * $Id: ViewScheduleLinear.php 417 2006-12-06 22:58:53Z ipso $
 * $Date: 2006-12-06 14:58:53 -0800 (Wed, 06 Dec 2006) $
 */
require_once('../../includes/global.inc.php');
require_once(Environment::getBasePath() .'includes/Interface.inc.php');

if ( !$permission->Check('schedule','enabled')
		OR !( $permission->Check('schedule','view') OR $permission->Check('schedule','view_own') ) ) {

	$permission->Redirect( FALSE ); //Redirect

}

$title = 'My Schedule';
$smarty->assign('title', $title);
BreadCrumb::setCrumb($title);

/*
 * Get FORM variables
 */
extract	(FormVariables::GetVariables(
										array	(
												'action',
												'page',
												'sort_column',
												'sort_order',
												'filter_start_date',
												'filter_end_date',
												'filter_user_ids'
												) ) );

URLBuilder::setURL($_SERVER['SCRIPT_NAME'],
											array(
													'sort_column' => $sort_column,
													'sort_order' => $sort_order,
													'page' => $page
												) );


switch (strtolower($action)) {
	case 'filter':
		if ( $filter_start_date != '' AND $filter_end_date != '' ) {
			$start_date = $filter_start_date = TTDate::parseDateTime($filter_start_date);
			$end_date = $filter_end_date = TTDate::parseDateTime($filter_end_date);

			if ( $start_date >= $end_date ) {
				$filter_start_date = $filter_end_date = NULL;
			}

			//90 day limit.
			if ( $end_date - $start_date > (86400 * 90) ) {
				$end_date = $start_date + (86400 * 90);
			}
		}
	default:
		if ( $permission->Check('schedule','view') ) {
			Debug::text('Viewing all users schedule', __FILE__, __LINE__, __METHOD__,10);
			if ( $filter_user_ids != '' ) {
				$user_ids = $filter_user_ids;
			} else {
				$user_ids = array($current_user->getId());
			}
		} else {
			$user_ids = array($current_user->getId());
		}

		if ( $filter_start_date == '' OR $filter_end_date == '' ) {
			$start_date = $filter_start_date = TTDate::getBeginWeekEpoch( TTDate::getTime() - 86400 );
			$end_date = $filter_end_date = TTDate::getEndWeekEpoch( TTDate::getTime() + ( 86400 * 28 ) );
		}

		$start_date = $filter_start_date = TTDate::getBeginWeekEpoch( $start_date, 'mon');
		$end_date = $filter_end_date = TTDate::getEndWeekEpoch( $end_date, 'mon' );

		Debug::text(' Start Date: '. TTDate::getDate('DATE+TIME', $start_date) .' End Date: '. TTDate::getDate('DATE+TIME', $end_date) , __FILE__, __LINE__, __METHOD__,10);

		$total_users = count($user_ids);

		$ssf = new ScheduleShiftFactory();
		foreach($user_ids as $user_id ) {
			$tmp_schedule_array = $ssf->getScheduleArray( $user_id, $start_date, $end_date);

			if ( is_array($tmp_schedule_array) ) {
				$tmp_default_schedule_shifts[$user_id] = $tmp_schedule_array;
			}
		}
		unset($tmp_schedule_array);

		//var_dump($tmp_default_schedule_shifts);


		if ( isset($tmp_default_schedule_shifts) ) {

			foreach($tmp_default_schedule_shifts as $user_id => $tmp_default_schedule_user_shifts) {
				foreach($tmp_default_schedule_user_shifts as $begin_day_epoch => $tmp_default_schedule_user_shift) {
					$default_schedule_shifts[$begin_day_epoch][$user_id] = $tmp_default_schedule_user_shifts[$begin_day_epoch];
				}
			}
			unset($tmp_default_schedule_shifts, $begin_day_epoch);
			ksort($default_schedule_shifts);

			//Loop over shifts, find the min start date and the max end date so we can
			//set the limits of the output.
			$i=0;
			foreach($default_schedule_shifts as $epoch => $default_schedule_user_shift) {
				foreach($default_schedule_user_shift as $default_schedule_shift) {
					$tmp_start_hour = date('H', $default_schedule_shift['start_date']);
					$tmp_end_hour = date('H', $default_schedule_shift['end_date']);

					if ( $i == 0 OR $tmp_start_hour <  $min_hour ) {
						$min_hour = $tmp_start_hour;
						if ( $min_hour > 0 ) {
							$min_hour--;
						}
					}

					if ( $i == 0 OR $tmp_end_hour > $max_hour ) {
						$max_hour = $tmp_end_hour;
						Debug::text(' aSetting Max Hour: '. $max_hour, __FILE__, __LINE__, __METHOD__,10);

						if ( $max_hour < 23 ) {
							$max_hour++;
						}
						Debug::text(' bSetting Max Hour: '. $max_hour, __FILE__, __LINE__, __METHOD__,10);
					}

					$i++;
				}
			}
			unset($tmp_start_hour,$tmp_end_hour, $i);
			Debug::text(' Min Hour: '. $min_hour.' Max Hour: '. $max_hour, __FILE__, __LINE__, __METHOD__,10);

			//Find out how many hours to span
			$total_span_hours = abs($max_hour - $min_hour);
			Debug::text(' Total Hours Span: '. $total_span_hours, __FILE__, __LINE__, __METHOD__,10);

			if ( $min_hour > $max_hour) {
				$tmp_max_hour = $max_hour+24;
				$tmp_min_hour = $min_hour;
			} else {
				$tmp_max_hour = $max_hour;
				$tmp_min_hour = $min_hour;
			}

			//Generate smarty array for table header
			for($i=$tmp_min_hour; $i < $tmp_max_hour; $i++) {
				$header_hours[] = array('hour' => TTDate::getTimeStamp( "","","", $i ) );
			}
			unset($tmp2_min_hour, $tmp_min_hour, $tmp_max_hour);
			//var_dump($header_hours);

			$ulf = new UserListFactory();

			//Format array so Smarty has an easier time.
			$i=0;
			$prev_start_date=NULL;
			foreach($default_schedule_shifts as $begin_day_epoch => $default_schedule_user_shift) {
				Debug::text('I: '. $i .' aBegin Day Epoch: '. TTDate::getDate('DATE+TIME', $begin_day_epoch), __FILE__, __LINE__, __METHOD__,10);

				foreach($user_ids as $user_id) {

					if ( $prev_start_date != $begin_day_epoch ) {
						$show_date = TRUE;
					} else {
						$show_date = FALSE;
					}

					if ( isset($default_schedule_shifts[$begin_day_epoch][$user_id]) ) {
						$shifts[$i] = $default_schedule_shifts[$begin_day_epoch][$user_id];
						$shifts[$i]['user_id'] = $user_id;
						$shifts[$i]['full_name'] = $ulf->getById( $user_id )->getCurrent()->getFullName();
						$shifts[$i]['show_date'] = $show_date;

						//Round dates to 15mins.
						$tmp_start_date = TTDate::roundTime( $default_schedule_shifts[$begin_day_epoch][$user_id]['start_date'], 900 );
						$tmp_lunch_start_date = TTDate::roundTime( $default_schedule_shifts[$begin_day_epoch][$user_id]['lunch_start_date'], 900 );
						$tmp_lunch_end_date = TTDate::roundTime( $default_schedule_shifts[$begin_day_epoch][$user_id]['lunch_end_date'], 900 );
						$tmp_end_date = TTDate::roundTime( $default_schedule_shifts[$begin_day_epoch][$user_id]['end_date'], 900 );

						$tmp_min_start_date = TTDate::getTimeStamp( date('Y', $tmp_start_date),date('m', $tmp_start_date),date('d', $tmp_start_date), $min_hour );
						$tmp_max_end_date = TTDate::getTimeStamp( date('Y', $tmp_end_date),date('m', $tmp_end_date),date('d', $tmp_end_date), $max_hour );

						//Determine if shift starts at the beginning of the table

						Debug::text(' Min Start Date: '. TTDate::getDate('DATE+TIME', $tmp_min_start_date) .' Start Date: '. TTDate::getDate('DATE+TIME', $tmp_start_date) , __FILE__, __LINE__, __METHOD__,10);
						Debug::text(' Max End Date: '. TTDate::getDate('DATE+TIME', $tmp_max_end_date) .' End Date: '. TTDate::getDate('DATE+TIME', $tmp_end_date) , __FILE__, __LINE__, __METHOD__,10);
						Debug::text('Start Date: '. $tmp_start_date .' Min Start Date: '. $tmp_min_start_date , __FILE__, __LINE__, __METHOD__,10);

						$shifts[$i]['columns'][] = array(
															'span' => abs($tmp_start_date - $tmp_min_start_date) / 900,
															'working' => FALSE );

						//Do they have a lunch scheduled?
						if ( $tmp_lunch_start_date != '' ) {
							$shifts[$i]['columns'][] = array(
																'span' => ($tmp_lunch_start_date - $tmp_start_date) / 900,
																'working' => TRUE );
							$shifts[$i]['columns'][] = array(
																'span' => ($tmp_lunch_end_date - $tmp_lunch_start_date) / 900,
																'working' => FALSE );
							$shifts[$i]['columns'][] = array(
																'span' => ($tmp_end_date - $tmp_lunch_end_date) / 900,
																'working' => TRUE );
							Debug::text(' End Date: '. TTDate::getDate('DATE+TIME', $tmp_end_date) .' Lunch End Date: '. TTDate::getDate('DATE+TIME', $tmp_lunch_end_date) .' Lunch Start Date: '. TTDate::getDate('DATE+TIME', $tmp_lunch_start_date), __FILE__, __LINE__, __METHOD__,10);
						} else {
							$shifts[$i]['columns'][] = array(
																'span' => ($tmp_end_date - $tmp_start_date) / 900,
																'working' => TRUE );
						}

						Debug::text(' Max End Date: '. TTDate::getDate('DATE+TIME', $tmp_max_end_date) .' End Date: '. TTDate::getDate('DATE+TIME', $tmp_end_date) , __FILE__, __LINE__, __METHOD__,10);
						Debug::text(' bMax End Date: '. abs($tmp_max_end_date - $tmp_end_date) / 900 , __FILE__, __LINE__, __METHOD__,10);
						$shifts[$i]['columns'][] = array(
															'span' => abs($tmp_max_end_date - $tmp_end_date) / 900,
															'working' => FALSE );

					} else {

						Debug::text(' Filling in blank shift: '. $i, __FILE__, __LINE__, __METHOD__,10);
						Debug::text(' Begin Day Epoch: '. TTDate::getDate('DATE+TIME', $begin_day_epoch) .' - Start Date '. TTDate::getDate('DATE+TIME', $prev_start_date) , __FILE__, __LINE__, __METHOD__,10);
						//$shifts[$i]['start_date'] = $prev_start_date;
						$shifts[$i]['show_date'] = $show_date;
						$shifts[$i]['start_date'] = $begin_day_epoch;
						$shifts[$i]['user_id'] = $user_id;
						$shifts[$i]['full_name'] = $ulf->getById( $user_id )->getCurrent()->getFullName();
					}

					$prev_start_date = $begin_day_epoch;
					$i++;
				}
			}


			//var_dump($shifts);
			$smarty->assign_by_ref('header_hours', $header_hours);
			$smarty->assign_by_ref('total_span_hours', $total_span_hours);
			$smarty->assign('column_widths', round( floor(99 / $total_span_hours) / 4 ) );
		}

		$smarty->assign_by_ref('filter_start_date', $filter_start_date);
		$smarty->assign_by_ref('filter_end_date', $filter_end_date);

		$user_options = UserListFactory::getByCompanyIdArray( $current_company->getId(), FALSE );
		$smarty->assign_by_ref('user_options', $user_options);
		$smarty->assign_by_ref('filter_user_ids', $user_ids);
		$smarty->assign_by_ref('total_users', $total_users );

		$smarty->assign_by_ref('schedule_shifts', $shifts);

		break;
}
$smarty->display('schedule/ViewScheduleLinear.tpl');
?>